@@ -22,6 +22,10 @@ class RCServer(TCPServer, CommandExecutor):
     def __str__(self):
         return '<RCServer>'
 
+    @property
+    def started(self):
+        return self._started
+
     def add_unix_socket(self, socket):
         """
         helper method to add file-based socket by path.
@@ -41,7 +45,11 @@ class RCServer(TCPServer, CommandExecutor):
             try:
                 command = yield stream.read_until(b'\n')
                 try:
-                    result = self.handle_command(command.decode().strip())
+                    cmd = command.decode().strip()
+                    if cmd == "quit":
+                        stream.close()
+                        break
+                    result = self.handle_command(cmd)
                 except TypeError as e:
                     result = 'Error: {}'.format(e)
                 yield stream.write(result.encode() + RC_PROMPT_PREFIX)
